Summary:	Administrative utilities for the XFS filesystem
Name:		xfsdump
Version:	3.2.0
Release:	%mkrel 2
License:	GPLv2
Group:		System/Kernel and hardware
URL:		https://xfs.org/index.php/Getting_the_latest_source_code
Source0:	https://www.kernel.org/pub/linux/utils/fs/xfs/xfsdump/%{name}-%{version}.tar.gz
BuildRequires:	pkgconfig(libattr)
BuildRequires:	pkgconfig(ext2fs)
BuildRequires:	xfs-devel
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	libtool
Requires(pre):	filesystem >= 2.1.9-18

%description
The xfsdump package contains xfsdump, xfsrestore and a number of
other utilities for administering XFS filesystems.

xfsdump examines files in a filesystem, determines which need to be
backed up, and copies those files to a specified disk, tape or other
storage medium.  It uses XFS-specific directives for optimizing the
dump of an XFS filesystem, and also knows how to backup XFS extended
attributes.  Backups created with xfsdump are "endian safe" and can
thus be transferred between Linux machines of different architectures
and also between IRIX machines.

xfsrestore performs the inverse function of xfsdump; it can restore a
full backup of a filesystem.  Subsequent incremental backups can then
be layered on top of the full backup.  Single files and directory
subtrees may be restored from full or partial backups.

%prep
%setup -q

%build
%configure
%make_build

%install
make install DIST_ROOT=%{buildroot}/

%find_lang %{name}

# nuke files already packaged as %%doc
rm -rf %{buildroot}%{_datadir}/doc/xfsdump/

# for coerency, rename xfsdump|xfsrestore to dump|restore.xfs
mv %{buildroot}/sbin/xfsdump %{buildroot}%{_sbindir}/dump.xfs
mv %{buildroot}/sbin/xfsrestore %{buildroot}%{_sbindir}/restore.xfs
ln -sf dump.xfs %{buildroot}%{_sbindir}/xfsdump
ln -sf restore.xfs %{buildroot}%{_sbindir}/xfsrestore
ln -sf %{_mandir}/man8/xfsdump.8 %{buildroot}%{_mandir}/man8/dump.xfs
ln -sf %{_mandir}/man8/xfsrestore.8 %{buildroot}%{_mandir}/man8/restore.xfs

%files -f %{name}.lang
%doc doc/CHANGES.gz doc/README.xfsdump
%license doc/COPYING
%{_sbindir}/*
%{_mandir}/*/*


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 3.2.0-2.mga10
+ Revision: 2227708
- Mageia 10 Mass Rebuild

* Sun Sep 15 2024 daviddavid <daviddavid> 3.2.0-1.mga10
+ Revision: 2096921
- new version: 3.2.0

* Thu Apr 25 2024 daviddavid <daviddavid> 3.1.12-1.mga10
+ Revision: 2060915
- new version: 3.1.12

* Wed Oct 19 2022 ghibo <ghibo> 3.1.11-1.mga9
+ Revision: 1897550
- Update to release 3.1.11

* Wed Mar 30 2022 umeabot <umeabot> 3.1.9-2.mga9
+ Revision: 1834653
- Mageia 9 Mass Rebuild
+ tv <tv>
- use %%make_build

* Tue Mar 03 2020 tv <tv> 3.1.9-1.mga8
+ Revision: 1553475
- 3.1.9
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 3.1.8-2.mga7
+ Revision: 1301902
- Mageia 7 Mass Rebuild

* Tue Nov 21 2017 tmb <tmb> 3.1.8-1.mga7
+ Revision: 1178135
- update to 3.1.8
- update url and source url

* Sun Mar 13 2016 tv <tv> 3.1.6-1.mga6
+ Revision: 990286
- new release

* Mon Feb 08 2016 umeabot <umeabot> 3.1.4-4.mga6
+ Revision: 943250
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 3.1.4-3.mga5
+ Revision: 740772
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.1.4-2.mga5
+ Revision: 690652
- Mageia 5 Mass Rebuild

* Sun Sep 07 2014 tmb <tmb> 3.1.4-1.mga5
+ Revision: 673350
- update to 3.1.4

* Tue Oct 22 2013 umeabot <umeabot> 3.1.3-2.mga4
+ Revision: 541711
- Mageia 4 Mass Rebuild

* Sat Jul 20 2013 fwang <fwang> 3.1.3-1.mga4
+ Revision: 456426
- new version 3.1.3

* Mon Jan 14 2013 umeabot <umeabot> 3.1.2-2.mga3
+ Revision: 386930
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 tmb <tmb> 3.1.2-1.mga3
+ Revision: 339697
- add translations
- update to 3.1.2

* Sat Jul 21 2012 colin <colin> 3.1.0-2.mga3
+ Revision: 273158
- Update for usrmove

* Sun Mar 25 2012 tmb <tmb> 3.1.0-1.mga2
+ Revision: 226158
- update to 3.1.0 (bugfixes for restoring)

* Sat Oct 15 2011 tmb <tmb> 3.0.6-1.mga2
+ Revision: 155318
- update to 3.0.6

* Thu Apr 14 2011 pterjan <pterjan> 3.0.5-2.mga1
+ Revision: 84822
- Re-upload after upload bug

* Wed Apr 13 2011 tv <tv> 3.0.5-1.mga1
+ Revision: 84633
- new release

* Thu Feb 24 2011 ennael <ennael> 3.0.4-2.mga1
+ Revision: 58813
- clean spec file
- imported package xfsdump


* Sat Dec 04 2010 Oden Eriksson <oeriksson@mandriva.com> 3.0.4-2mdv2011.0
+ Revision: 608208
- rebuild

* Sat Feb 13 2010 Frederik Himpe <fhimpe@mandriva.org> 3.0.4-1mdv2010.1
+ Revision: 505168
- Update to new version 3.0.4

* Wed May 06 2009 Frederik Himpe <fhimpe@mandriva.org> 3.0.1-1mdv2010.0
+ Revision: 372682
- Update to new version 3.0.1
- Don't run aclocal and autoconf: it breaks build and is not needed

* Thu Feb 05 2009 Frederik Himpe <fhimpe@mandriva.org> 3.0.0-1mdv2009.1
+ Revision: 337896
- Update to new version 3.0.0
- Drop format string patch, not needed anymore

* Tue Dec 23 2008 Oden Eriksson <oeriksson@mandriva.com> 2.2.48-3mdv2009.1
+ Revision: 317971
- fix build with -Werror=format-security (P0)

* Wed Jun 18 2008 Thierry Vignaud <tv@mandriva.org> 2.2.48-2mdv2009.0
+ Revision: 226040
- rebuild

* Mon Feb 11 2008 Frederik Himpe <fhimpe@mandriva.org> 2.2.48-1mdv2008.1
+ Revision: 165618
- New upstream version
- Remove patch applied upstream

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Aug 27 2007 Thierry Vignaud <tv@mandriva.org> 2.2.42-4mdv2008.0
+ Revision: 72077
- patch 0: fix CVE-2007-2654 (#31522)


* Sat Mar 03 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2.2.42-3mdv2007.0
+ Revision: 131817
- commented perl regexp in %%setup section as configure file is not yet created at that stage.
- Import xfsdump

* Tue Sep 19 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.2.42-2mdv2007.0
- Rebuild

* Sat Aug 26 2006 Giuseppe Ghibò <ghibo@mandriva.com> 2.2.42-1mdv2007.0
- Release 2.2.42.

* Sun Jul 09 2006 Giuseppe Ghibò <ghibo@mandriva.com> 2.2.38-1mdv2007.0
- Release 2.2.38.

* Sat May 06 2006 Giuseppe Ghibò <ghibo@mandriva.com> 2.2.33-1mdk
- Release 2.2.33.

* Wed Jan 11 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 2.2.30-3mdk
- add BuildRequires: libtool

* Sun Jan 01 2006 Mandriva Linux Team <http://www.mandrivaexpert.com/> 2.2.30-2mdk
- Rebuild

* Wed Aug 03 2005 Giuseppe Ghibò <ghibo@mandriva.com> 2.2.30-1mdk
- 2.2.30.
- Renamed xfsdump|xfsrestore to dump|restore.xfs (pixel).
- Removed Patch0 (merged upstream).

* Sun Jul 31 2005 Nicolas Lécureuil <neoclust@mandriva.org> 2.2.21-2mdk
- Patch 0 : Fix build with Gcc4

* Sun May 23 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 2.2.21-1mdk
- 2.2.21.

* Fri Apr 30 2004 Juan Quintela <quintela@mandrakesoft.com> 2.2.19-1mdk
- 2.2.19.

